@@ -1,5 +1,5 @@
 '''
-*! version 0.1.2  15mar2021
+*! version 0.1.3  11may2022
 
 A module for configuring and initializing Stata within Python.
 
@@ -9,13 +9,13 @@ This code is under the
 from __future__ import absolute_import, print_function
 
 __all__ = ["config"]
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __author__ = 'StataCorp LLC'
 
 import os
 import sys
 
-def config(path, edition):
+def config(path, edition, splash=True):
     """
     Configure Stata within Python.
 
@@ -26,6 +26,13 @@ def config(path, edition):
 	
     edition : str
         The Stata edition to be used. It can be one of mp, se, or be.
+        
+    splash  : bool, optional 
+        Suppress displaying the splash message after Stata is successfully 
+        initialized. Default is True. When set to False, the splash will be 
+        suppressed.
+
+        *New in version 0.1.3*.
     """	
     if not os.path.isdir(path):
         raise OSError(path + ' is invalid')
@@ -35,4 +42,4 @@ def config(path, edition):
 
     sys.path.append(os.path.join(path, 'utilities'))
     from pystata import config 
-    config.init(edition)
+    config.init(edition, splash=splash)
